==> eole-limesurvey_2.51.3+1-5.tar.gz: eole-limesurvey-5/src/limesurvey-2.51.3/application/views/admin/survey/newSurvey_view.php <==
<?php
/**
 * Create survey
 */
?>
<!-- new survey view -->
<?php
    extract($data);
    Yii::app()->loadHelper('admin/htmleditor');
    PrepareEditorScript(false, $this);
    $active = (isset($_GET['tab']))?$_GET['tab']:'create';
?>
<script type="text/javascript">
    standardtemplaterooturl='<?php echo Yii::app()->getConfig('standardtemplaterooturl');?>';
    templaterooturl='<?php echo Yii::app()->getConfig('usertemplaterooturl');?>';
</script>

<h3 class="pagetitle"><?php eT("Create, import, or copy survey"); ?></h3>
<div class="row" style="margin-bottom: 100px">
    <div class="col-lg-12">
        <!-- tabs -->
        <?php $this->renderPartial('/admin/survey/subview/tab_survey_view',$data); ?>

        <!-- tabs content -->
        <div class="tab-content">
            <!-- General Tab (contains accrodion) -->
            <div id="general" class="tab-pane fade in <?php if($active=='create'){echo ' active ';}?>">
                <?php $this->renderPartial('/admin/survey/subview/tabCreate_view',array('data'=>$data));?>
            </div>

            <!-- Import -->
            <div id='import'  class="tab-pane fade in <?php if($active=='import'){echo ' active ';}?>">
                <?php $this->renderPartial('/admin/survey/subview/tabImport_view',$data); ?>
            </div>

            <!-- Copy -->
            <div id='copy' class="tab-pane fade in <?php if($active=='copy'){echo ' active ';}?>" >
                <?php $this->renderPartial('/admin/survey/subview/tabCopy_view',$data); ?>
            </div>
        </div>
    </div>
</div>

==> eole-limesurvey_3.26.2+6-5.tar.gz: eole-limesurvey-5/src/limesurvey-3.13.1/application/views/admin/survey/newSurvey_view.php <==
<?php
/**
 * Create survey
 * @var AdminController $this
 * @var Survey $oSurvey
 */

// DO NOT REMOVE This is for automated testing to validate we see that page
echo viewHelper::getViewTestTag('createSurvey');

?>
<!-- new survey view -->
<?php
    extract($data);
    Yii::app()->loadHelper('admin/htmleditor');
    PrepareEditorScript(false, $this);
    $active = (isset($_GET['tab']))?$_GET['tab']:'create';
?>
<script type="text/javascript">
    standardthemerooturl='<?php echo Yii::app()->getConfig('standardthemerooturl');?>';
    templaterooturl='<?php echo Yii::app()->getConfig('userthemerooturl');?>';
</script>

<div class="pagetitle h3"><?php eT("Create, import, or copy survey"); ?></div>
<div class="row" style="margin-bottom: 100px">
    <div class="col-lg-12">
        <!-- tabs -->
        <?php $this->renderPartial('/admin/survey/subview/tab_survey_view',$data); ?>

        <!-- tabs content -->
        <div class="tab-content">
            <!-- General Tab (contains accrodion) -->
            <div id="general" class="tab-pane fade in <?php if($active=='create'){echo ' active ';}?>">
                <?php $this->renderPartial('/admin/survey/subview/tabCreate_view',array('data'=>$data));?>
            </div>

            <!-- Import -->
            <div id='import'  class="tab-pane fade in <?php if($active=='import'){echo ' active ';}?>">
                <?php $this->renderPartial('/admin/survey/subview/tabImport_view',$data); ?>
            </div>

            <!-- Copy -->
            <div id='copy' class="tab-pane fade in <?php if($active=='copy'){echo ' active ';}?>" >
                <?php $this->renderPartial('/admin/survey/subview/tabCopy_view',$data); ?>
            </div>
        </div>
    </div>
</div>
